<?php

namespace Drupal\commerce_gnu_taler\PluginForm;

use Drupal\commerce_gnu_taler\Plugin\Commerce\PaymentGateway\TalerInterface;
use Drupal\commerce_payment\Entity\PaymentInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\commerce_payment\PluginForm\PaymentOffsiteForm as BasePaymentOffsiteForm;

/**
 * Provides the GNU Taler payment form.
 */
class PaymentForm extends BasePaymentOffsiteForm {

  /**
   * {@inheritdoc}
   *
   * @phpstan-param mixed[] $form
   * @phpstan-return mixed[]
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    assert(is_string($form['#return_url']));
    assert(is_string($form['#cancel_url']));

    $payment = $this->entity;
    assert($payment instanceof PaymentInterface);
    $gatewayPlugin = $payment->getPaymentGateway()?->getPlugin();
    assert($gatewayPlugin instanceof TalerInterface);

    $form = parent::buildConfigurationForm($form, $form_state);

    ['url' => $url, 'data' => $data] = $gatewayPlugin->createRedirectOrder(
      $payment,
      $form['#return_url'],
      $form['#cancel_url'],
    );

    return $this->buildRedirectForm($form, $form_state, $url, $data);
  }

}
